/*
 * Copyright (c) 2023 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*
 * @file	generic/cpu.h
 * @brief	Generic CPU specific primitives
 */

#ifndef __METAL_GENERIC_CPU__H__
#define __METAL_GENERIC_CPU__H__

#define metal_cpu_yield()

#endif /* __METAL_GENERIC_CPU__H__ */
